@@ -10,7 +10,9 @@ use parent qw(MyCPAN::Indexer::Component);
 use subs qw(get_caller_info);
 use vars qw($VERSION $logger);
 
-$VERSION = '1.28_12';
+$VERSION = '1.281';
+
+=encoding utf8
 
 =head1 NAME
 
@@ -485,7 +487,7 @@ my @refs = (
 	\ $Archive::TAR::WARN,
 	);
 
-sub _archive_extract_subclass { 
+sub _archive_extract_subclass {
 	my $class = 'Archive::Extract::Libarchive';
 	eval "use $class; 1";
 	$class;
@@ -1636,6 +1638,18 @@ sub get_test_info
 
 =item count_lines( FILE )
 
+Counts the lines in a file and categorizes them as code, comment, documentation, or blank.
+
+This returns a hash:
+
+	{
+	total         => ...,
+	code          => ...,
+	comment       => ...,
+	documentation => ...,
+	blank         => ...,
+	}
+
 =cut
 
 sub count_lines
@@ -1667,7 +1681,8 @@ sub count_lines
 
 =item file_magic( FILE )
 
-Guesses and returns the MIME type for the file.
+Guesses and returns the MIME type for the file, using File::MMagic if
+it's available. If that module is not available, it returns nothing.
 
 =cut
 
@@ -1801,7 +1816,7 @@ sub getppid
 
 =over 4
 
-=item Count the lines in the files
+=item Count the lines in the files. I think this is currently broken.
 
 =item Code stats? Lines of code, lines of pod, lines of comments
 
@@ -1819,9 +1834,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2008-2013, brian d foy, All Rights Reserved.
+Copyright © 2008-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
-You may redistribute this under the same terms as Perl itself.
+You may redistribute this under the terms of the Artistic License 2.0.
 
 =cut
 
